"use strict";
/**
 * @module frest-json
 */
/**
 *    Copyright 2018 Panjie Setiawan Wicaksono
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *        http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var error_1 = tslib_1.__importDefault(require("./error"));
var request_1 = tslib_1.__importDefault(require("./request"));
var response_1 = tslib_1.__importDefault(require("./response"));
/**
 * Create JSON interceptors set.
 *
 * @remarks
 * Specify an option for each type of interceptor to enable them. Unspecified
 * option will make the interceptor not created.
 *
 * @param opts - Options for each type of JSON interceptors.
 */
function jsonInterceptors(opts) {
    if (opts === void 0) { opts = {}; }
    return {
        error: opts.error ? error_1.default(opts.error) : undefined,
        request: opts.request ? request_1.default(opts.request) : undefined,
        response: opts.response ? response_1.default(opts.response) : undefined,
    };
}
exports.default = jsonInterceptors;
